@@ -110,7 +110,7 @@ public:
         return a->m_label < b->m_label;
     }
 
-signals:
+Q_SIGNALS:
     void selected( int gameId );
     void hoverChanged( GameSelectionBox * box, bool hovered );
 
@@ -118,19 +118,19 @@ protected:
     void mousePressEvent( QGraphicsSceneMouseEvent * event ) override
     {
         Q_UNUSED( event )
-        emit selected( m_gameId );
+        Q_EMIT selected( m_gameId );
     }
 
     void hoverEnterEvent( QGraphicsSceneHoverEvent * event ) override
     {
         Q_UNUSED( event )
-        emit hoverChanged( this, true );
+        Q_EMIT hoverChanged( this, true );
     }
 
     void hoverLeaveEvent( QGraphicsSceneHoverEvent * event ) override
     {
         Q_UNUSED( event )
-        emit hoverChanged( this, false );
+        Q_EMIT hoverChanged( this, false );
     }
 
     qreal hoverFadeAmount() const
@@ -211,8 +211,8 @@ GameSelectionScene::GameSelectionScene( QObject * parent )
   : QGraphicsScene( parent ),
     m_selectionIndex( -1 )
 {
-    foreach (const DealerInfo * i, DealerInfoList::self()->games())
-    {
+    const auto games = DealerInfoList::self()->games();
+    for (const DealerInfo * i : games) {
         GameSelectionBox * box = new GameSelectionBox( i->baseName(), i->baseId() );
         m_boxes.append( box );
         addItem( box );
@@ -293,8 +293,7 @@ void GameSelectionScene::resizeScene( const QSize & size )
     int row = 0;
     int col = 0;
 
-    foreach ( GameSelectionBox * box, m_boxes )
-    {
+    for (GameSelectionBox * box : qAsConst(m_boxes)) {
         // Reduce font size until the label fits
         while ( pixelFontSize > minimumFontSize
                 && p.boundingRect( QRectF(), box->label() ).width() > maxLabelWidth )
@@ -362,7 +361,7 @@ void GameSelectionScene::keyReleaseEvent( QKeyEvent * event )
                 || event->key() ==Qt::Key_Space )
               && m_selectionIndex != -1 )
     {
-        emit gameSelected( m_boxes.at( m_selectionIndex )->id() );
+        Q_EMIT gameSelected( m_boxes.at( m_selectionIndex )->id() );
     }
 }
 
